@@ -9,7 +9,7 @@
  * Copyright 2001, Ximian, Inc.
  *                 Martin Baulig.
  */
-#include <gdk/gdkx.h>
+#include "config.h"
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkwindow.h>
 #include <gtk/gtksignal.h>
@@ -18,6 +18,9 @@
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-control-frame.h>
 #include <bonobo/bonobo-control-internal.h>
+#if defined (GDK_WINDOWING_X11)
+#include <gdk/gdkx.h>
+#endif
 #include <libgnome/gnome-macros.h>
 
 
@@ -33,7 +36,7 @@ typedef struct {
 	/* Whether a descendant of us has the focus.  If this is the case, it
 	 * means that we are out-of-process.
 	 */
-	gboolean descendant_has_focus : 1;
+	guint descendant_has_focus : 1;
 } BonoboSocketPrivate;
 
 GNOME_CLASS_BOILERPLATE (BonoboSocket, bonobo_socket,
